==> carbon-components-react-0.8.1.tgz: package/es/components/SplitButton/SplitButton-story.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { storiesOf } from '@storybook/react';
import { action } from '@storybook/addon-actions';
import { withKnobs, boolean, select } from '@storybook/addon-knobs';
import SplitButton from '../SplitButton';
import OverflowMenuItem from '../OverflowMenuItem';
var sizes = {
  Default: 'default',
  Field: 'field',
  Small: 'small'
};
var props = {
  regular: function regular() {
    return {
      classNameContainer: 'some-class',
      classNameButton: 'some-class',
      classNameOverflow: 'some-class',
      size: select('Button size (size)', sizes, 'default'),
      disabled: boolean('Disabled (disabled)', false)
    };
  },
  items: function items() {
    return {
      onClick: action('onClick')
    };
  }
};
SplitButton.displayName = 'Button';
storiesOf('Pattern|SplitButton', module).addDecorator(withKnobs).add('Default', function () {
  var regularProps = props.regular();
  var itemProps = props.items();
  return /*#__PURE__*/React.createElement(SplitButton, regularProps, /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 1'
  }, itemProps)), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 2'
  }, itemProps)), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 3'
  }, itemProps)), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 4'
  }, itemProps)));
}, {
  info: {
    text: "\n        A split button can be used to group a series of actions together into a single location on the screen, providing \n        the user with a single primary action and a small list of alternative actions. \n        "
  }
});

==> carbon-components-react-2.0.3.tgz: package/es/components/SplitButton/SplitButton-story.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { action } from '@storybook/addon-actions';
import { withKnobs, boolean, select } from '@storybook/addon-knobs';
import SplitButton from '../SplitButton';
import OverflowMenuItem from '../OverflowMenuItem';
var sizes = {
  Default: 'default',
  Field: 'field',
  Small: 'small'
};
var props = {
  regular: function regular() {
    return {
      classNameContainer: 'some-class',
      classNameButton: 'some-class',
      classNameOverflow: 'some-class',
      size: select('Button size (size)', sizes, 'default'),
      disabled: boolean('Disabled (disabled)', false)
    };
  },
  items: function items() {
    return {
      onClick: action('onClick')
    };
  }
};
SplitButton.displayName = 'Button';
export default {
  title: 'RocketPatterns/SplitButton',
  decorators: [withKnobs],
  parameters: {
    component: SplitButton
  }
};
export var _Default = function _Default() {
  return /*#__PURE__*/React.createElement(SplitButton, props.regular(), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 1'
  }, props.items())), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 2'
  }, props.items())), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 3'
  }, props.items())), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({
    itemText: 'Item 4'
  }, props.items())));
};
